@@ -3,9 +3,9 @@ use super::constants::{
     DEFAULT_APP_OBJECT, PIPEBASE_MAIN,
 };
 use super::context::ContextStore;
+use super::dependency::Dependency;
 use super::error::ErrorHandler;
 use super::meta::{metas_to_literal, Meta, MetaValue};
-use super::package::Dependency;
 use super::pipe::Pipe;
 use super::utils::indent_literal;
 use super::{Entity, EntityAccept, Object, VisitEntity};
